# Color system

⚠️ The color system is currently an unstable API, and is subject to change in non-major releases of Polaris react. Please use with caution.

## Table of contents

- [surface](#surface)
- [onSurface](#onSurface)
- [interactive](#interactive)
- [neutral](#neutral)
- [primary](#primary)
- [critical](#critical)
- [warning](#warning)
- [highlight](#highlight)
- [success](#success)
- [decorative](#decorative)
- [Overrides](#Overrides)

## surface

[↑ Back to top](#table-of-contents)

The surface role is used for the backgrounds of the UI. In light mode, surface colors are nearly white, while in dark mode, surface colors are nearly black. The color passed to the surface role impacts the rest of the color roles and their variants, adjusting them for light or dark contexts.

| CSS variable                              | Description                                                                                                                                                                         | Light mode                                                                                                         | Dark mode                                                                                                          |
| ----------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-surface</pre>                    | While use directly in our components is discouraged, the base variant is unmodified from the original role input color. `-inverse`, `-light`, and `-dark` variants available.       | ![](https://www.gifpng.com/64x64/fafafa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/111213/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-surface-background</pre>         | For use in the background of our UIs as a background color, in components such as Page and Frame backgrounds. `-inverse`, `-light`, and `-dark` variants available.                 | ![](https://www.gifpng.com/64x64/fafafa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/0c0d0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-surface-foreground</pre>         | For use in the foreground of our UIs as a background color, in components such as Card, Modal, and Popover. `-inverse`, `-light`, and `-dark` variants available.                   | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/202122/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-surface-foreground-subdued</pre> | For use in the foreground of our UIs as a subdued background color, in components such as Card, Modal, and Popover. `-inverse`, `-light`, and `-dark` variants available.           | ![](https://www.gifpng.com/64x64/fafafa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/1b1d1d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-surface-hovered</pre>            | For use as a surface color on interactive elements such as resource list items and action list items when in a hovered state. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/f2f2f2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/2f3032/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-surface-pressed</pre>            | For use as a surface color on interactive elements such as resource list items and action list items when in a pressed state. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/e3e3e3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/3d3f42/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-backdrop</pre>                   | For use as the background color of the backdrop component for navigation and modal.                                                                                                 | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-shadow-from-ambient-light</pre>  | For use in building shadows for popovers, cards, and modals.                                                                                                                        | ![](https://www.gifpng.com/64x64/161717/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/161717/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-shadow-from-direct-light</pre>   | For use in building shadows for popovers, cards, and modals.                                                                                                                        | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/000000/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## onSurface

[↑ Back to top](#table-of-contents)

The onSurface role is made up of elements which appear on top of a surface, including borders, neutral icons, and text. When a light surface is provided, onSurface values will be dark. When a dark surface is provided, onSurface values will be light.

| CSS variable                              | Description                                                                                                             | Light mode                                                                                                         | Dark mode                                                                                                          |
| ----------------------------------------- | ----------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-on-surface</pre>                 | While use directly in our components is discouraged, the base variant is unmodified from the original role input color. | ![](https://www.gifpng.com/64x64/111213/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/111213/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-border-on-surface</pre>          | For use as a border (border or interactive outline). `-inverse`, `-light`, and `-dark` variants available.              | ![](https://www.gifpng.com/64x64/b5babf/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/515458/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-border-disabled-on-surface</pre> | For use as a an interactive outline on disabled elements. `-inverse`, `-light`, and `-dark` variants available.         | ![](https://www.gifpng.com/64x64/f1f2f3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/a5abb1/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-border-subdued-on-surface</pre>  | For use as a subdued border (border or interactive outline). `-inverse`, `-light`, and `-dark` variants available.      | ![](https://www.gifpng.com/64x64/d3d6d9/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/4a4d4f/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-icon-on-surface</pre>            | For use as the fill color of neutral icons. `-inverse`, `-light`, and `-dark` variants available.                       | ![](https://www.gifpng.com/64x64/5c5e61/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/a5abb1/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-icon-disabled-on-surface</pre>   | For use as the fill color of disabled neutral icons. `-inverse`, `-light`, and `-dark` variants available.              | ![](https://www.gifpng.com/64x64/bbbfc4/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/545759/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-icon-subdued-on-surface</pre>    | For use as the fill color of subdued neutral icons. `-inverse`, `-light`, and `-dark` variants available.               | ![](https://www.gifpng.com/64x64/8c9197/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/787d82/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-text-on-surface</pre>            | For use as a neutral text color. `-inverse`, `-light`, and `-dark` variants available.                                  | ![](https://www.gifpng.com/64x64/202222/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/e3e6e8/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-text-disabled-on-surface</pre>   | For use as a disabled neutral text color. `-inverse`, `-light`, and `-dark` variants available.                         | ![](https://www.gifpng.com/64x64/8f9499/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/6f7376/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-text-subdued-on-surface</pre>    | For use as a subdued neutral text color. `-inverse`, `-light`, and `-dark` variants available.                          | ![](https://www.gifpng.com/64x64/6c7075/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/989fa4/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## interactive

[↑ Back to top](#table-of-contents)

The interactive role is used to express interactivity in components. It is used in links, as an indicator of focus, and as an indicator of selected interactive states.

| CSS variable                                | Description                                                                                                                                                                              | Light mode                                                                                                         | Dark mode                                                                                                          |
| ------------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-interactive</pre>                  | While use directly in our components is discouraged, the base variant is unmodified from the original role input color.                                                                  | ![](https://www.gifpng.com/64x64/2d72d2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/2d72d2/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-action</pre>           | Used for links and plain buttons. `-inverse`, `-light`, and `-dark` variants available.                                                                                                  | ![](https://www.gifpng.com/64x64/2d72d2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/38a5ff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-action-disabled</pre>  | Used for disabled links and plain buttons. `-inverse`, `-light`, and `-dark` variants available.                                                                                         | ![](https://www.gifpng.com/64x64/4a8af2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/2662b5/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-action-hovered</pre>   | Used for hovered links and plain buttons. `-inverse`, `-light`, and `-dark` variants available.                                                                                          | ![](https://www.gifpng.com/64x64/2156a1/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/66adff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-action-subdued</pre>   | Used for subdued links and plain buttons. `-inverse`, `-light`, and `-dark` variants available.                                                                                          | ![](https://www.gifpng.com/64x64/3279dc/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/3074d5/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-action-pressed</pre>   | Used for pressed links and plain buttons. `-inverse`, `-light`, and `-dark` variants available.                                                                                          | ![](https://www.gifpng.com/64x64/1a4889/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/8abdff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-focus</pre>            | For use in the focus ring on interactive elements. `-inverse`, `-light`, and `-dark` variants available.                                                                                 | ![](https://www.gifpng.com/64x64/4a8af2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/2662b5/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-selected</pre>         | For use as a surface color in selected interactive elements, in components such as option list and resource list. `-inverse`, `-light`, and `-dark` variants available.                  | ![](https://www.gifpng.com/64x64/f1f4fe/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/020e22/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-selected-hovered</pre> | For use as a surface color in selected interactive elements that are hovered, in components such as option list and resource list. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/d4defc/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/071c3b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-interactive-selected-pressed</pre> | For use as a surface color in selected interactive elements that are pressed, in components such as option list and resource list. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/b9c9f9/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/0d2a54/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## neutral

[↑ Back to top](#table-of-contents)

A neutral interactive color role, for use in secondary and tertiary buttons as a background color, as well as in form elements as a background color.

| CSS variable                           | Description                                                                                                                                                                                       | Light mode                                                                                                         | Dark mode                                                                                                          |
| -------------------------------------- | ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-neutral</pre>                 | While use directly in our components is discouraged, the base variant is unmodified from the original role input color.                                                                           | ![](https://www.gifpng.com/64x64/111213/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/111213/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-neutral-action</pre>          | Used for secondary buttons and tertiary buttons, as well as in form elements as a background color and pontentially other neutral surfaces. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/eaebec/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/333638/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-neutral-action-disabled</pre> | Used as a disabled state for secondary buttons `-inverse`, `-light`, and `-dark` variants available.                                                                                              | ![](https://www.gifpng.com/64x64/ecedee/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/202222/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-neutral-action-hovered</pre>  | Used as a hovered state for secondary buttons `-inverse`, `-light`, and `-dark` variants available.                                                                                               | ![](https://www.gifpng.com/64x64/e1e3e5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/53565a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-neutral-action-pressed</pre>  | Used as a pressed state for secondary buttons `-inverse`, `-light`, and `-dark` variants available.                                                                                               | ![](https://www.gifpng.com/64x64/d9dbde/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/5f6467/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## primary

[↑ Back to top](#table-of-contents)

A primary interactive color, for use in primary buttons as a background color. Also used in navigation and tabs for icons, and for a surface color when in a selected state.

| CSS variable                            | Description                                                                                                                                                                                                                  | Light mode                                                                                                         | Dark mode                                                                                                          |
| --------------------------------------- | ---------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-primary</pre>                  | While use directly in our components is discouraged, the base variant is unmodified from the original role input color.                                                                                                      | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-primary-action</pre>           | Used as the background color for primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.                                                               | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-primary-action-disabled</pre>  | Used as the background color for disabled primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states.                                                      | ![](https://www.gifpng.com/64x64/005741/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/005741/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-primary-action-hovered</pre>   | Used as the background color for hovered primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/007054/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/00946f/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-primary-action-pressed</pre>   | Used as the background color for pressed primary actions, and as the fill color for icons and the text color in navigation and tabs to communicate interaction states. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/00664d/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/00a37a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-icon-on-primary</pre>          | For use as a fill color for icons on primary actions. Not for use in icons on navigation and tabs.                                                                                                                           | ![](https://www.gifpng.com/64x64/e5fff4/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/e5fff4/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-text-on-primary</pre>          | For use as a text color on primary actions. Not for use in text on navigation and tabs.                                                                                                                                      | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-primary-selected</pre>         | Used as a surface color to indicate selected interactive states in navigation and tabs. `-inverse`, `-light`, and `-dark` variants available.                                                                                | ![](https://www.gifpng.com/64x64/e1f5ec/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/0c1210/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-primary-selected-hovered</pre> | Used as a surface color to indicate selected interactive states that are hovered in navigation and tabs. `-inverse`, `-light`, and `-dark` variants available.                                                               | ![](https://www.gifpng.com/64x64/b3d0c3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/272f2b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-primary-selected-pressed</pre> | Used as a surface color to indicate selected interactive states that are pressed in navigation and tabs. `-inverse`, `-light`, and `-dark` variants available.                                                               | ![](https://www.gifpng.com/64x64/a3bdb1/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/363f3b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## critical

[↑ Back to top](#table-of-contents)

Used to communicate destructive outcomes on interactive elements, for communicating errors, and to indicate a critical event in inert elements that requires immediate merchant action.

| CSS variable                                    | Description                                                                                                                                                                                                                | Light mode                                                                                                         | Dark mode                                                                                                          |
| ----------------------------------------------- | -------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-critical</pre>                         | While use directly in our components is discouraged, the base variant is unmodified from the original role input color.                                                                                                    | ![](https://www.gifpng.com/64x64/d92b0d/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/d92b0d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-border</pre>                  | For use as a border on critical components such as banners, and as an outline on interactive elements in an error state.                                                                                                   | ![](https://www.gifpng.com/64x64/e12e0e/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/e12e0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-border-disabled</pre>         | For use as a disabled border on critical components such as banners, and as an outline on interactive elements in an error state. `-inverse`, `-light`, and `-dark` variants available.                                    | ![](https://www.gifpng.com/64x64/febcb9/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/811704/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-icon</pre>                    | For use as an icon fill color on top of critical elements. `-inverse`, `-light`, and `-dark` variants available.                                                                                                           | ![](https://www.gifpng.com/64x64/eb300f/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/d92b0d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-surface</pre>                 | For use as a surface color on critical elements including badges. `-inverse`, `-light`, and `-dark` variants available.                                                                                                    | ![](https://www.gifpng.com/64x64/fffafa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/460701/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-surface-subdued</pre>         | For use as a subdued surface color on critical elements including banners. `-inverse`, `-light`, and `-dark` variants available.                                                                                           | ![](https://www.gifpng.com/64x64/fff6f5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/460701/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-surface-subdued-hovered</pre> | For use as a surface color on critical interactive elements including action list items in a hovered state. `-inverse`, `-light`, and `-dark` variants available.                                                          | ![](https://www.gifpng.com/64x64/fff0f0/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/431714/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-surface-subdued-pressed</pre> | For use as a surface color on critical interactive elements including action list items in a pressed state. `-inverse`, `-light`, and `-dark` variants available.                                                          | ![](https://www.gifpng.com/64x64/fed4d2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/6d1103/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-text</pre>                    | For use as a text color in inert critical elements such as exception list. Not for use as a text color on banners and badges. `-inverse`, `-light`, and `-dark` variants available.                                        | ![](https://www.gifpng.com/64x64/d92b0d/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ea817b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-action</pre>                  | For use as the background color for destructive buttons, and as the background color for error toast messages. `-inverse`, `-light`, and `-dark` variants available.                                                       | ![](https://www.gifpng.com/64x64/d92b0d/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/cf290c/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-action-disabled</pre>         | For use as the background color for disabled destructive buttons, and as the background color for error toast messages. `-inverse`, `-light`, and `-dark` variants available.                                              | ![](https://www.gifpng.com/64x64/fd4f3f/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/bd250a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-action-hovered</pre>          | For use as the background color for hovered destructive buttons, and as the background color for error toast messages. `-inverse`, `-light`, and `-dark` variants available.                                               | ![](https://www.gifpng.com/64x64/c2260a/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/e12e0e/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-action-pressed</pre>          | For use as the background color for pressed destructive buttons, and as the background color for error toast messages. `-inverse`, `-light`, and `-dark` variants available.                                               | ![](https://www.gifpng.com/64x64/aa2008/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/fa320f/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-icon-on-critical</pre>                 | For use as a fill color for icons on critical actions.                                                                                                                                                                     | ![](https://www.gifpng.com/64x64/fff6f5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/fff6f5/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-text-on-critical</pre>                 | For use as a text color on critical actions.                                                                                                                                                                               | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-link</pre>                    | For use as a text color in destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges. `-inverse`, `-light`, and `-dark` variants available.          | ![](https://www.gifpng.com/64x64/dd2d0e/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/fd7068/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-link-disabled</pre>           | For use as a text color in disabled destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/fd918b/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/feada9/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-link-hovered</pre>            | For use as a text color in hovered destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges. `-inverse`, `-light`, and `-dark` variants available.  | ![](https://www.gifpng.com/64x64/cf290c/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/fd8881/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-critical-link-pressed</pre>            | For use as a text color in pressed destructive plain buttons, as well as a text color on destructive action list items. Not for use on critical banners and badges. `-inverse`, `-light`, and `-dark` variants available.  | ![](https://www.gifpng.com/64x64/680f03/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/fd9e9b/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## warning

[↑ Back to top](#table-of-contents)

For use as an indicator that action should be taken by merchants in components including badges, banners, and exception lists.

| CSS variable                           | Description                                                                                                                                                                         | Light mode                                                                                                         | Dark mode                                                                                                          |
| -------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-warning</pre>                 | While use directly in our components is discouraged, the base variant is unmodified from the original role input color.                                                             | ![](https://www.gifpng.com/64x64/ffc252/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ffc252/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-warning-border</pre>          | For use as a border on warning components such as banners. `-inverse`, `-light`, and `-dark` variants available.                                                                    | ![](https://www.gifpng.com/64x64/f0b400/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/997000/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-warning-icon</pre>            | For use as an icon fill color on top of warning elements. `-inverse`, `-light`, and `-dark` variants available.                                                                     | ![](https://www.gifpng.com/64x64/cc9600/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/664900/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-warning-surface</pre>         | For use as a surface color on warning elements including badges. `-inverse`, `-light`, and `-dark` variants available.                                                              | ![](https://www.gifpng.com/64x64/ffcd75/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/997000/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-warning-surface-subdued</pre> | For use as a subdued surface color on warning elements including banners. `-inverse`, `-light`, and `-dark` variants available.                                                     | ![](https://www.gifpng.com/64x64/fff1e0/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/4e3c1d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-warning-text</pre>            | For use as a text color in inert critical elements such as exception list. Not for use as a text color on banners and badges. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/8f6900/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/cc9600/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## highlight

[↑ Back to top](#table-of-contents)

Used to highlight elements of the UI that are important for merchants, but do not require immediate action. Used in information banners and badges, indicators that draw attention to new information, bars that indicate loading or progress, and in data visualization.

| CSS variable                             | Description                                                                                                                                                       | Light mode                                                                                                         | Dark mode                                                                                                          |
| ---------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-highlight</pre>                 | While use directly in our components is discouraged, the base variant is unmodified from the original role input color.                                           | ![](https://www.gifpng.com/64x64/5dceda/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/5dceda/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-highlight-border</pre>          | For use as a border on informational components such as banners.                                                                                                  | ![](https://www.gifpng.com/64x64/449da7/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/449da7/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-highlight-icon</pre>            | For use as an icon fill color on top of informational elements. `-inverse`, `-light`, and `-dark` variants available.                                             | ![](https://www.gifpng.com/64x64/41969f/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/2b6c73/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-highlight-surface</pre>         | For use as a surface color on information elements including badges. `-inverse`, `-light`, and `-dark` variants available.                                        | ![](https://www.gifpng.com/64x64/8ee0eb/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/006970/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-highlight-surface-subdued</pre> | For use as a surface color on information elements including banners. `-inverse`, `-light`, and `-dark` variants available.                                       | ![](https://www.gifpng.com/64x64/f6fdfe/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/12363a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-highlightext</pre>              | For use as a text color in inert informational elements. Not for use as a text color on banners and badges. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/081f21/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/a3effa/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## success

[↑ Back to top](#table-of-contents)

Used to indicate the result of a successful action taken by a merchant, to indicate a positive event, or to illustrate growth.

| CSS variable                           | Description                                                                                                                                                 | Light mode                                                                                                         | Dark mode                                                                                                          |
| -------------------------------------- | ----------------------------------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-success</pre>                 | While use directly in our components is discouraged, the base variant is unmodified from the original role input color.                                     | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-success-border</pre>          | For use as a border on success components such as banners.                                                                                                  | ![](https://www.gifpng.com/64x64/008563/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/008563/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-success-icon</pre>            | For use as an icon fill color on top of success elements. `-inverse`, `-light`, and `-dark` variants available.                                             | ![](https://www.gifpng.com/64x64/004231/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/005c45/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-success-surface</pre>         | For use as a surface color on success elements including badges. `-inverse`, `-light`, and `-dark` variants available.                                      | ![](https://www.gifpng.com/64x64/8ae5c2/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/005c45/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-success-surface-subdued</pre> | For use as a surface color on information elements including banners. `-inverse`, `-light`, and `-dark` variants available.                                 | ![](https://www.gifpng.com/64x64/f6fefa/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/1c352c/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-success-text</pre>            | For use as a text color in inert success elements. Not for use as a text color on banners and badges. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/008060/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/58ad8d/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## decorative

[↑ Back to top](#table-of-contents)

Used to decorate elements where color does convey a specific meaning in components like avatars

| CSS variable                            | Description                                                                                                                       | Light mode                                                                                                         | Dark mode                                                                                                          |
| --------------------------------------- | --------------------------------------------------------------------------------------------------------------------------------- | ------------------------------------------------------------------------------------------------------------------ | ------------------------------------------------------------------------------------------------------------------ |
| <pre>--p-decorative-one-surface</pre>   | For use as a decorative surface color. `-inverse`, `-light`, and `-dark` variants available.                                      | ![](https://www.gifpng.com/64x64/ffc96b/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/906709/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-one-text</pre>      | For use as a decorative text color that is applied on a decorative surface. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/3d2800/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-two-surface</pre>   | For use as a decorative surface color. `-inverse`, `-light`, and `-dark` variants available.                                      | ![](https://www.gifpng.com/64x64/ffc6b3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/cc5814/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-two-text</pre>      | For use as a decorative text color that is applied on a decorative surface. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/470b1b/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-three-surface</pre> | For use as a decorative surface color. `-inverse`, `-light`, and `-dark` variants available.                                      | ![](https://www.gifpng.com/64x64/91e3b3/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/007a5a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-three-text</pre>    | For use as a decorative text color that is applied on a decorative surface. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/002e18/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-four-surface</pre>  | For use as a decorative surface color. `-inverse`, `-light`, and `-dark` variants available.                                      | ![](https://www.gifpng.com/64x64/90e0d5/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/167e7a/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-four-text</pre>     | For use as a decorative text color that is applied on a decorative surface. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/002e2e/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-five-surface</pre>  | For use as a decorative surface color. `-inverse`, `-light`, and `-dark` variants available.                                      | ![](https://www.gifpng.com/64x64/fdc9d0/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/c13357/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |
| <pre>--p-decorative-five-text</pre>     | For use as a decorative text color that is applied on a decorative surface. `-inverse`, `-light`, and `-dark` variants available. | ![](https://www.gifpng.com/64x64/4e0e1f/FFFFFF?border-width=16&border-type=rectangle&border-color=fafafa&text=%20) | ![](https://www.gifpng.com/64x64/ffffff/FFFFFF?border-width=16&border-type=rectangle&border-color=0c0d0e&text=%20) |

---

## Overrides

[↑ Back to top](#table-of-contents)

| CSS variable                              | Value                                                                                             |
| ----------------------------------------- | ------------------------------------------------------------------------------------------------- |
| `--p-border-radius-base`                  | `0.4rem`                                                                                          |
| `--p-border-radius-wide`                  | `0.8rem`                                                                                          |
| `--p-card-shadow`                         | `0px 0px 5px var(--p-shadow-from-ambient-light), 0px 1px 2px var(--p-shadow-from-direct-light)`   |
| `--p-popover-shadow`                      | `-1px 0px 20px var(--p-shadow-from-ambient-light), 0px 1px 5px var(--p-shadow-from-direct-light)` |
| `--p-modal-shadow`                        | `0px 6px 32px var(--p-shadow-from-ambient-light), 0px 1px 6px var(--p-shadow-from-direct-light)`  |
| `--p-override-none`                       | `none`                                                                                            |
| `--p-override-transparent`                | `transparent`                                                                                     |
| `--p-override-one`                        | `1`                                                                                               |
| `--p-override-visible`                    | `visible`                                                                                         |
| `--p-override-zero`                       | `0`                                                                                               |
| `--p-override-loading-z-index`            | `514`                                                                                             |
| `--p-button-font-weight`                  | `500`                                                                                             |
| `--p-non-null-content`                    | `''`                                                                                              |
| `--p-banner-default-border`               | `inset 0 0.2rem 0 0 var(--p-border-on-surface), inset 0 0 0 0.2rem var(--p-border-on-surface)`    |
| `--p-banner-success-border`               | `inset 0 0.2rem 0 0 var(--p-success-border), inset 0 0 0 0.2rem var(--p-success-border)`          |
| `--p-banner-highlight-border`             | `inset 0 0.2rem 0 0 var(--p-highlight-border), inset 0 0 0 0.2rem var(--p-highlight-border)`      |
| `--p-banner-warning-border`               | `inset 0 0.2rem 0 0 var(--p-warning-border), inset 0 0 0 0.2rem var(--p-warning-border)`          |
| `--p-banner-critical-border`              | `inset 0 0.2rem 0 0 var(--p-critical-border), inset 0 0 0 0.2rem var(--p-critical-border)`        |
| `--p-badge-mix-blend-mode`                | `luminosity`                                                                                      |
| `--p-border-subdued`                      | `0.1rem solid var(--p-border-subdued-on-surface)`                                                 |
| `--p-text-field-spinner-offset`           | `0.2rem`                                                                                          |
| `--p-text-field-focus-ring-offset`        | `-0.4rem`                                                                                         |
| `--p-text-field-focus-ring-border-radius` | `0.7rem`                                                                                          |
| `--p-button-group-item-spacing`           | `0.2rem`                                                                                          |
